@@ -99,61 +99,63 @@ has '_drmaa_job_template' => (
 	is       => 'ro',
 	lazy     => 1,
 	init_arg => undef,
-	default  => sub {
-		my $self    = shift;
-		my $jt      = $self->Odrmaa_allocate_job_template;
-		my $args    = $self->_qsub_args;
-		my $skipped = $self->_qsub_args_skipped;
-		my $stage   = $self->stage;
-		my $extra   = $stage->extra_sge_args_string;
-		$extra =~ s/^\s*//;
-		while ($extra) {
-			$extra =~ s/^(-\w+)\s*\b//
-				or croak "No known qsub option ($extra)";
-			my $key = $1;
-			my $p = $_qaparse{$key}
-				or croak "No known qsub option ($key $extra)";
-			my $val  = $self->$p( $key, \$extra );
-			my $disp = $_qadisp{$key};
-			$disp = $self->$disp($val);
-			if (exists $_qaattr{$key}) {
-				my $attr = $_qaattr{$key};
-				if ($attr =~ /^\s*$/) {
-					$attr = '';
-				}
-				else {
-					$attr = " from stage attr ($attr)";
-				}
-				$stage->warn( "ignoring ($key $disp) from extra_sge_args_string, it is determined internally$attr" );
-				push @$skipped, $key;
-				push @$skipped, $disp if defined $disp;
+	builder  => '_init_drmaa_job_template',
+);
+
+sub _init_drmaa_job_template {
+	my $self    = shift;
+	my $jt      = $self->Odrmaa_allocate_job_template;
+	my $args    = $self->_qsub_args;
+	my $skipped = $self->_qsub_args_skipped;
+	my $stage   = $self->stage;
+	my $extra   = $stage->extra_sge_args_string;
+	$extra =~ s/^\s*//;
+	while ($extra) {
+		$extra =~ s/^(-\w+)\s*\b//
+			or croak "No known qsub option ($extra)";
+		my $key = $1;
+		my $p = $_qaparse{$key}
+			or croak "No known qsub option ($key $extra)";
+		my $val  = $self->$p( $key, \$extra );
+		if (exists $_qaattr{$key}) {
+			my $attr = $_qaattr{$key};
+			if ($attr =~ /^\s*$/) {
+				$attr = '';
 			}
 			else {
-				$self->set( $jt, $key, $val );
-				push @$args, $key;
-				push @$args, $disp if defined $disp;
+				$attr = " from stage attr ($attr)";
 			}
+			$stage->warn( "ignoring ($key $val) from extra_sge_args_string, it is determined internally$attr" );
+			push @$skipped, $key;
+			push @$skipped, $val if defined $val;
 		}
-		for my $pair (
-			(   [ '-N', $self->unique_id ],
-				[ '-l', $stage->_use_resources_required ],
-				[ '-o', $self->_stdout ],
-				[ '-e', $self->_stderr ],
-				[ '-cwd', get_cwd() ],
-				[ 'SCRIPT', $stage->script_file ]
-			) ) {
-			my ($key, $val) = @$pair;
+		else {
 			$self->set( $jt, $key, $val );
-			push @$args, $key unless $key eq 'SCRIPT';
-			if (defined $val) {
-				my $disp = $_qadisp{$key};
-				$disp = $self->$disp($val);
-				push @$args, $disp;
-			}
+			my $disp = $_qadisp{$key};
+			$disp = $self->$disp($val);
+			push @$args, $key;
+			push @$args, $disp if defined $disp;
 		}
-		return $jt;
 	}
-);
+	for my $pair (
+		(   [ '-N', $self->unique_id ],
+			[ '-l', $stage->_use_resources_required ],
+			[ '-o', $self->_stdout ],
+			[ '-e', $self->_stderr ],
+			[ '-cwd', get_cwd() ],
+			[ 'SCRIPT', $stage->script_file ]
+		) ) {
+		my ($key, $val) = @$pair;
+		$self->set( $jt, $key, $val );
+		push @$args, $key unless $key eq 'SCRIPT';
+		if (defined $val) {
+			my $disp = $_qadisp{$key};
+			$disp = $self->$disp($val);
+			push @$args, $disp;
+		}
+	}
+	return $jt;
+}
 
 sub str1_parse {
 	my $self      = shift;
