@@ -160,8 +160,8 @@ sub _vmem_usage {
 					? "  ** Requested resource too large"
 					: "";
 	my $loglevel = $warn ? 'warn' : 'info';
-	$self->$loglevel( sprintf "Resource(%s): Requested(%s) Usage(%s) %.2f%%%s",
-		'h_vmem', $dreq, $dused, $pct, $warn );
+	$self->$loglevel( sprintf "Resource(%s): Requested(%s) Usage(%s) %.2f%%%s Stage(%s), Run(%s)",
+		'h_vmem', $dreq, $dused, $pct, $warn, $run->stage->name, $run->index );
 	my $stderr = $run->_stderr;
 	my $cmd  = "tail -1 $stderr";
 	my $last = `$cmd`;
